summaryrefslogtreecommitdiff
path: root/libebl/libebl.h
diff options
context:
space:
mode:
authorRoland McGrath <roland@redhat.com>2010-01-04 21:59:07 -0800
committerRoland McGrath <roland@redhat.com>2010-01-04 21:59:07 -0800
commit0ccbbcd1244336d38f51648620b32b193d591cbb (patch)
treebccb82dbe2a1c9a403b15f5f6e17c77c04068d33 /libebl/libebl.h
parent2e79deb2cb049f3b0f3f45680dfe956cf99b25d8 (diff)
downloadelfutils-0ccbbcd1244336d38f51648620b32b193d591cbb.tar.gz
Make readelf -n check note name strings, handle "VMCOREINFO" flavor.
Diffstat (limited to 'libebl/libebl.h')
-rw-r--r--libebl/libebl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libebl/libebl.h b/libebl/libebl.h
index 1a56b966..c94ad78f 100644
--- a/libebl/libebl.h
+++ b/libebl/libebl.h
@@ -1,5 +1,5 @@
/* Interface for libebl.
- Copyright (C) 2000, 2001-2009 Red Hat, Inc.
+ Copyright (C) 2000-2010 Red Hat, Inc.
This file is part of Red Hat elfutils.
Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -379,13 +379,13 @@ typedef struct
bool thread_identifier;
} Ebl_Core_Item;
-/* Describe the format of a core file note with type field matching N_TYPE
- and descriptor size matching DESCSZ. */
-extern int ebl_core_note (Ebl *ebl, GElf_Word n_type, GElf_Word descsz,
+/* Describe the format of a core file note with the given header and NAME.
+ NAME is not guaranteed terminated, it's NHDR->n_namesz raw bytes. */
+extern int ebl_core_note (Ebl *ebl, const GElf_Nhdr *nhdr, const char *name,
GElf_Word *regs_offset, size_t *nregloc,
const Ebl_Register_Location **reglocs,
size_t *nitems, const Ebl_Core_Item **items)
- __nonnull_attribute__ (1, 4, 5, 6, 7, 8);
+ __nonnull_attribute__ (1, 2, 3, 4, 5, 6, 7, 8);
/* Describe the auxv type number. */
extern int ebl_auxv_info (Ebl *ebl, GElf_Xword a_type,